--[[
CanolaStraw

Specialization to allow straw for canola

Author: 	Ifko[nator]
Date: 		06.08.2020
Version:	1.0

History:	v1.0 @06.08.2020 - initial implemation in FS 19
]]

CanolaStraw = {};

function CanolaStraw:loadFruitTypeWindrow(superFunc, fruitType, xmlFile, key)
	local canola = g_fruitTypeManager:getFruitTypeByName("canola");

	if canola ~= nil then
		local windrowFillType = g_fillTypeManager:getFillTypeByName("straw");
		
		canola.hasWindrow = true;
		canola.windrowName = windrowFillType.name;
		canola.windrowLiterPerSqm = 3.68;
		self.windrowFillTypes[windrowFillType.index] = true;
		self.fruitTypeIndexToWindrowFillTypeIndex[canola.index] = windrowFillType.index;
		self.fillTypeIndexToFruitTypeIndex[windrowFillType.index] = canola.index;
	end;
	
	if fruitType ~= nil and fruitType.name ~= "CANOLA" then
		local windrowName = getXMLString(xmlFile, key .. ".windrow#name");
		local windrowLitersPerSqm = getXMLFloat(xmlFile, key .. ".windrow#litersPerSqm");

		if windrowName == nil or windrowLitersPerSqm == nil then
			return true;
		end;

		local windrowFillType = g_fillTypeManager:getFillTypeByName(windrowName);

		if windrowFillType == nil then
			print("Warning: Missing fillType '" .. tostring(windrowName) .. "' for windrow definition. Ignoring windrow!");

			return false;
		end;

		fruitType.hasWindrow = true;
		fruitType.windrowName = windrowFillType.name;
		fruitType.windrowLiterPerSqm = windrowLitersPerSqm;
		self.windrowFillTypes[windrowFillType.index] = true;
		self.fruitTypeIndexToWindrowFillTypeIndex[fruitType.index] = windrowFillType.index;
		self.fillTypeIndexToFruitTypeIndex[windrowFillType.index] = fruitType.index;
	end;

	return true;
end;

FruitTypeManager.loadFruitTypeWindrow = Utils.overwrittenFunction(FruitTypeManager.loadFruitTypeWindrow, CanolaStraw.loadFruitTypeWindrow)